==> kpl-2.2.tar.bz2: kpl-2.2/kpl/kpldoubleedit.h <==
/***************************************************************************
                          kpldoubleedit.h  -  description
                             -------------------
    begin                : Tue Aug 15 2000
    copyright            : (C) 2001 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KPLDOUBLEEDIT_H
#define KPLDOUBLEEDIT_H

#include <qlineedit.h>

class QDoubleValidator;

/**
  * Double value line edit class. Provides a QLineEdit widget with validator.
  * @author Werner Stille
  */
class KplDoubleEdit : public QLineEdit
{
public:
  /**
   * Constructor.
   * @param val initial double value.
   * @param minVal minimum value.
   * @param maxVal maximum value.
   * @param parent pointer to parent widget.
   * @param format format string for value display.
   */
	KplDoubleEdit(double val, double minVal, double maxVal, QWidget* parent,
                const char* format = "%.2lf");
  /** Destructor. */
	~KplDoubleEdit();
  /**
   * Sets, fixups, and returns value.
   * @param val double value.
   * @return value.
   */
  double setValue(double val);
  /**
   * Fixups and returns value.
   * @return value.
   */
  double value();

protected:
  /** Reimplemented for fixup of text. */
  virtual void focusOutEvent(QFocusEvent*);
  QString frm;
  QDoubleValidator* validator;

  friend class FrameDlg;
};

#endif

==> kpl-3.0.tar.bz2: kpl-3.0/kpl/kpldoubleedit.h <==
/***************************************************************************
                          kpldoubleedit.h  -  description
                             -------------------
    begin                : Tue Aug 15 2000
    copyright            : (C) 2002 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KPLDOUBLEEDIT_H
#define KPLDOUBLEEDIT_H

#include <qlineedit.h>

class QDoubleValidator;

/**
  * Double value line edit class. Provides a QLineEdit widget with validator.
  * @author Werner Stille
  */
class KplDoubleEdit : public QLineEdit
{
public:
  /**
   * Constructor.
   * @param val initial double value.
   * @param parent pointer to parent widget.
   * @param format format string for value display.
   */
  KplDoubleEdit(double val, QWidget* parent, const char* format = "%.6lg");
  /**
   * Constructor.
   * @param val initial double value.
   * @param minVal minimum value.
   * @param maxVal maximum value.
   * @param parent pointer to parent widget.
   * @param format format string for value display.
   */
  KplDoubleEdit(double val, double minVal, double maxVal, QWidget* parent,
                const char* format = "%.2lf");
  /** Destructor. */
  ~KplDoubleEdit();
  /**
   * Sets, fixups, and returns value.
   * @param val double value.
   * @return value.
   */
  double setValue(double val);
  /**
   * Fixups and returns value.
   * @return value.
   */
  double value();
  /**
   * Sets lower limit of validator.
   * @param bottom lower limit.
   */
  void setBottom(double bottom);

protected:
  /** Reimplemented for fixup of text. */
  virtual void focusOutEvent(QFocusEvent*);
  QString frm;
  QDoubleValidator* validator;
};

#endif
